#
# spec file for package python-httptools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-httptools
Version:        0.6.1
Release:        1.4
Summary:        Python framework independent HTTP protocol utils
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/MagicStack/httptools
Source0:        https://github.com/MagicStack/httptools/archive/v%{version}.tar.gz#/httptools-%{version}.tar.gz
Source1:        https://github.com/nodejs/llhttp/archive/refs/tags/release/v6.0.6.tar.gz#/llhttp-release-v6.0.6.tar.gz
Source2:        https://github.com/nodejs/http-parser/archive/refs/tags/v2.9.4.tar.gz#/http-parser-2.9.4.tar.gz
# BuildRequires:  %{python_module Cython >= 0.29.24 with %python-Cython < 3}
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
httptools is a Python binding for the nodejs HTTP parser.

%prep
%setup -q -n httptools-%{version}
rm -df vendor/llhttp/
tar -xzf '%{SOURCE1}' -C vendor
mv vendor/llhttp-release*/ vendor/llhttp/
rm -df vendor/http-parser/
tar -xzf '%{SOURCE2}' -C vendor
mv vendor/http-parser*/ vendor/http-parser/

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%if 0%{suse_version} >= 1550
# pytest on suse <= 15.4 does not support the required pytest importlib import mode
%pytest_arch -k 'not test_parser_response_1'
%endif

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/httptools
%{python_sitearch}/httptools-%{version}.dist-info

%changelog
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * Explicit Python 3.12 support and build wheels, change min
    version to 3.8
  * Do not install the *.c sources in wheels
- update to 0.6.0 (bsc#1212582, CVE-2023-30589):
  * Bump bundled llhttp to 8.1.1
  * Fixes CVE-2023-30589
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- restrict to older Cython
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.5.0
  * Bump bundled llhttp to 6.0.9
  * fixes CVE-2022-32213, CVE-2022-32214, CVE-2022-32215
  (by @nlsj1985 in 56d6a16 for #83)
  * Test and build against Python 3.11
  (by @elprans in 509cd14 for #84)
* Mon Jul 18 2022 Ben Greiner <code@bnavigator.de>
- update to version 0.4.0
  * Bump bundled http-parser to 2.9.4 and llhttp to 6.0.6
    fixes CVE-2021-22959 & CVE-2021-22960
    (bsc#1191602 and bsc#1191601)
- The above was already the case for the rpm package
* Sun Jan  9 2022 Torsten Gruner <simmphonie@opensuse.org>
- update to version 0.3.0
  * Use cibuildwheel to build release wheels (by @elprans in 2f57b6b)
- version 0.2.0
  * Swap http-parse to llhttp
    (by @victoraugustolls and @fantix in 63b5de2 for #56)
  * Fix httptools.__all__
    (by @elprans in 9340d32 for #52)
  * Add Python 3.9 in the build/test matrix
    (by @b0g3r in e2d1a46 for #62)
- version 0.1.2
  * Fix httptools.__all__
    (by @elprans in 9340d32 for #52)
  * Add Python 3.9 in the build/test matrix
    (by @b0g3r in e2d1a46 for #62)
* Wed Jul 29 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.1.1
